@@ -7,7 +7,7 @@
 
 void BlitMenu();
 
-#define SDL_SetAlpha($1,$2,$3) SDL_SetAlpha($1,0,0);SDL_SetAlpha($1,$2,$3)
+#define SDL_SetAlpha(A,B,C) SDL_SetAlpha(A,0,0);SDL_SetAlpha(A,B,C)
 
 typedef struct{
   float       slowdown,turbo_possible,sticky_possible,extra_time;
