@@ -17,9 +17,6 @@ void ComplainAndExit(void);
 // Updates all blitted rects;
 void Update();
 
-// Draw a line
-void Line(Sint32 X1, Sint32 Y1, Sint32 X2, Sint32 Y2, Uint32 Color);
-
 // Puts a pixel (lock and unlock needed!)
 extern int PutPixel(SDL_Surface *Surface, Sint32 X, Sint32 Y, Uint32 Color);
 
@@ -49,4 +46,4 @@ SDL_Surface *LoadImage(char *datafile, int transparent);
 void Blit(int Xpos,int Ypos,SDL_Surface *image);
 void BlitToBB(int Xpos,int Ypos,SDL_Surface *image);   //blits to BackBuffer
 void BlitPart(int Xpos,int Ypos,SDL_Surface *image, SDL_Rect srcrect);
-int PutBackPixel(SDL_Surface *Surface, Sint32 x, Sint32 y);
\ No newline at end of file
+void PutBackPixel(SDL_Surface *Surface, Sint32 x, Sint32 y);
