@@ -112,7 +112,7 @@ void DisplayParticles()
   unlock();
 }
 
-void NewParticles(float turn, int X, int Y)
+void NewParticles(float turn, int X, int Y, float spread_percent)
 {
       if(( NullParticle < PARTICLES_OF_EXHAUST )&&(particle))
 	{
@@ -129,22 +129,7 @@ void NewParticles(float turn, int X, int Y)
 	  ThisParticle->G = ParticleColorsG[ ColorIndex ];
 	  ThisParticle->B = ParticleColorsB[ ColorIndex ];
 	  // Introduce Orthogonal (y, -x) Component
-	switch( user[pl].racernum ) {
-	    case 0: // SlowPoke
-	      Percent = abrand( -50, 50 );
-	      break;
-	    case 1: // Normal
-	      Percent = abrand( -25, 25 );
-	      break;
-	    case 2: // Speedy
-	      Percent = abrand( -5, 5 );
-	      break;
-	    case 3: // Spinny
-	      Percent = abrand( -60, 60 );
-	      break;
-	    default: // OOPS!
-	      Percent = 0;
-	}
+	Percent = abrand( -spread_percent/2, spread_percent/2 );
 	turn+=190;
 	turn+=Percent;
 	if (turn>360) turn-=360;
